@@ -239,14 +239,14 @@ class TextPairClassificationExplainaboardBuilder:
     def _print_bucket_info(self):
         for feature_name in self._performances_over_bucket.keys():
             print_dict(self._performances_over_bucket[feature_name], feature_name)
-        print("")
+
 
 
     def run(self) -> SysOutputInfo:
         eb_generator = self._complete_feature()
         self._bucketing_samples(eb_generator)
         self.get_overall_performance()
-        # self._print_bucket_info()
+        self._print_bucket_info()
         self._generate_report()
         return self._info
 
